package com.muyu.aliyun.service.impl;

import com.aliyun.oss.OSS;
import com.aliyun.oss.OSSClientBuilder;
import com.muyu.aliyun.bailian.AddDataManagement;
import com.muyu.aliyun.bailian.ApplyLease;
import com.muyu.aliyun.bailian.ReviewResolution;
import com.muyu.aliyun.bailian.TemporaryStorage;
import com.muyu.aliyun.bailian.data.FileUploadLeaseMode;
import com.muyu.aliyun.bailian.data.UploadDataManagementMode;
import com.muyu.aliyun.bailian.data.UploadDescribeFileMode;
import com.muyu.aliyun.bailian.data.UploadFileModel;
import com.muyu.aliyun.bailian.data.fixed.AddFileResponseBodyDataMode;
import com.muyu.aliyun.bailian.data.fixed.DescribeFileResponseBodyDataMode;
import com.muyu.aliyun.bailian.data.fixed.UploadLeaseParamsMode;
import com.muyu.aliyun.config.OssConfig;
import com.muyu.aliyun.service.KnowledgeBaseUploadService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.UUID;

import static com.muyu.aliyun.bailian.Md5Utils.getFileMd5;


@Service
public class KnowledgeBaseUploadServiceImpl implements KnowledgeBaseUploadService {

    @Autowired
    private ApplyLease applyLease;

    @Autowired
    private TemporaryStorage temporaryStorage;


    @Autowired
    private AddDataManagement addDataManagement;

    @Autowired
    private ReviewResolution reviewResolution;

    @Override
    public String uploadDocument(MultipartFile file, String workspaceId, String categoryId) {
        try {
            // 1. 保存临时文件
            File tempFile = convertMultipartFileToFile(file);
            // 获取文件大小
            long sizeInBytes = tempFile.length();

            // 2. 计算文件 MD5
            String md5 = getFileMd5(tempFile.getAbsolutePath());

            // 3. 申请文档上传租约
            FileUploadLeaseMode fileUploadLeaseModel = new FileUploadLeaseMode();
            fileUploadLeaseModel.setWorkspaceId(workspaceId);
            fileUploadLeaseModel.setCategoryId(categoryId);
            fileUploadLeaseModel.setFileName(file.getOriginalFilename());
            fileUploadLeaseModel.setMd5(md5);
            fileUploadLeaseModel.setSizeInBytes(String.valueOf(sizeInBytes));



            UploadLeaseParamsMode leaseParams = applyLease.applyFileUploadLease(fileUploadLeaseModel);
            if (leaseParams == null) {
                throw new RuntimeException("申请文档上传租约失败");
            }


            // 4. 上传文档至百炼的临时存储
            UploadFileModel uploadFileModel = new UploadFileModel();
            uploadFileModel.setPreSignedUrl(leaseParams.getUrl());
            uploadFileModel.setMethod(leaseParams.getMethod());
            // 这里需要根据实际情况设置 X-bailian-extra 和 Content-Type
            uploadFileModel.setBailianExtra("");
            uploadFileModel.setContentType("");
            uploadFileModel.setFilePath(tempFile.getAbsolutePath());
            temporaryStorage.uploadFile(uploadFileModel);

            // 5. 将文档添加至百炼的数据管理
            UploadDataManagementMode uploadDataManagementMode = new UploadDataManagementMode();
            uploadDataManagementMode.setWorkspaceId(workspaceId);
            // 这里需要设置 LeaseId，假设 LeaseId 在 UploadLeaseParamsMode 中有对应的 getter
            uploadDataManagementMode.setLeaseId(leaseParams.getLeaseId());
            AddFileResponseBodyDataMode addFileResult = addDataManagement.addFile(uploadDataManagementMode);
            if (addFileResult == null) {
                throw new RuntimeException("将文档添加至百炼的数据管理失败");
            }

            // 6. 查看文档解析状态
            UploadDescribeFileMode uploadDescribeFileMode = new UploadDescribeFileMode();
            uploadDescribeFileMode.setWorkspaceId(workspaceId);
            uploadDescribeFileMode.setFileId(addFileResult.getFileId());
            DescribeFileResponseBodyDataMode describeFileResult = reviewResolution.DescribeFile(uploadDescribeFileMode);
            if (describeFileResult == null) {
                throw new RuntimeException("查看文档解析状态失败");
            }

            // 清理临时文件
            tempFile.delete();

        } catch (IOException e) {
            e.printStackTrace();
        }
        return null;
    }


    private File convertMultipartFileToFile(MultipartFile file) throws IOException {
        Path tempFilePath = Files.createTempFile(null, null);
        File tempFile = tempFilePath.toFile();
        file.transferTo(tempFile);
        return tempFile;
    }


}
